@@ -94,6 +94,43 @@ class MemberHeader(xport.v56.MemberHeader):
             raise ValueError(f'Expected only padding, got {data}')
         return self
 
+    template = f'''\
+HEADER RECORD{'*' * 7}MEMBV8  HEADER RECORD{'!' * 7}{'0' * 17}16{'0' * 8}140  \
+HEADER RECORD{'*' * 7}DSCPTV8 HEADER RECORD{'!' * 7}{'0' * 30}  \
+SAS     %(name)32bSASDATA %(version)8b%(os)8b%(created)16b\
+%(modified)16b{' ' * 16}%(label)40b%(type)8b\
+HEADER RECORD{'*' * 7}NAMSTV8 HEADER RECORD{'!' * 7}{'0' * 6}\
+%(n_variables)04d{'0' * 20}  \
+%(namestrs)b\
+HEADER RECORD{'*' * 7}LABELV9 HEADER RECORD{'!' * 7}%(n_labels)5b{' ' * 27}\
+%(labels)b\
+HEADER RECORD{'*' * 7}OBS     HEADER RECORD{'!' * 7}{'0' * 30}  \
+'''.encode('ascii')
+
+    def __bytes__(self):
+        """
+        Encode in XPORT format.
+        """
+        namestrs = b''.join(map(bytes, self.values()))
+        if len(namestrs) % 80:
+            namestrs += b' ' * (80 - len(namestrs) % 80)
+        labels = b''  # TODO: Write the v8 long label section.
+        if len(labels) % 80:
+            labels += b' ' * (80 - len(labels) % 80)
+        return self.template % {
+            b'name': text_encode(self, 'name', 8),
+            b'label': text_encode(self, 'dataset_label', 40),
+            b'type': text_encode(self, 'dataset_type', 8),
+            b'n_variables': len(self),
+            b'n_labels': 0,
+            b'os': text_encode(self, 'sas_os', 8),
+            b'version': text_encode(self, 'sas_version', 8),
+            b'created': strftime(self.created if self.created else datetime.now()),
+            b'modified': strftime(self.modified if self.modified else datetime.now()),
+            b'namestrs': namestrs,
+            b'labels': labels,
+        }
+
 
 class Member(xport.v56.Member):
     """
